# HTML theme support

The Algolia DocSearch Sphinx extension works best for HTML themes that use dedicated templates to render the search box on every page
(`searchbox.html` or `sidebar/search.html`).

Out of the box, this extension supports these HTML themes for Sphinx:

- [Alabaster](https://alabaster.readthedocs.io/en/latest/)
- [Awesome Theme](https://sphinxawesome.xyz/)
- [Furo](https://pradyunsg.me/furo/)
- [Pydata Sphinx theme](https://pydata-sphinx-theme.readthedocs.io/en/stable/)
- [Read The Docs Sphinx Theme](https://sphinx-rtd-theme.readthedocs.io/en/stable/)

For other themes, you can add the DocSearch UI with [custom templates and custom CSS](/customization.md).
